@@ -667,12 +667,13 @@ pdf_document_get_info (EvDocument *document)
 		      "permissions", &permissions,
 		      "creator", &(info->creator),
 		      "producer", &(info->producer),
-		      "creation-date", &(info->creation_date),
-		      "mod-date", &(info->modified_date),
 		      "linearized", &linearized,
 		      "metadata", &metadata,
 		      NULL);
 
+	info->creation_date = (gint64) poppler_document_get_creation_date (PDF_DOCUMENT (document)->document);
+	info->modified_date = (gint64) poppler_document_get_modification_date (PDF_DOCUMENT (document)->document);
+
 	if (metadata != NULL) {
 		pdf_document_parse_metadata (metadata, info);
 		g_free (metadata);
@@ -2988,7 +2989,7 @@ pdf_document_annotations_add_annotation (EvDocumentAnnotations *document_annotat
 	annot_mapping->data = annot;
 	g_object_set_data_full (G_OBJECT (annot),
 				"poppler-annot",
-				g_object_ref (poppler_annot),
+				poppler_annot,
 				(GDestroyNotify) g_object_unref);
 
 	if (pdf_document->annots) {
