@@ -66,7 +66,6 @@ struct _EvAnnotationAttachmentClass {
 	EvAnnotationClass parent_class;
 };
 
-static void ev_annotation_markup_default_init          (EvAnnotationMarkupInterface *iface);
 static void ev_annotation_text_markup_iface_init       (EvAnnotationMarkupInterface *iface);
 static void ev_annotation_attachment_markup_iface_init (EvAnnotationMarkupInterface *iface);
 
@@ -455,7 +454,7 @@ ev_annotation_get_modified (EvAnnotation *annot)
  * @modified: string with the last modification date.
  *
  * Set the last modification date of @annot to @modified. To
- * set the last modification date using a #GTime, use
+ * set the last modification date using a #gint64, use
  * ev_annotation_set_modified_from_time() instead. You can monitor
  * changes to the last modification date by connecting to the
  * notify::modified signal on @annot.
@@ -483,7 +482,7 @@ ev_annotation_set_modified (EvAnnotation *annot,
 /**
  * ev_annotation_set_modified_from_time:
  * @annot: an #EvAnnotation
- * @utime: a #GTime
+ * @utime: a #gint64
  *
  * Set the last modification date of @annot to @utime.  You can
  * monitor changes to the last modification date by connectin to the
@@ -494,7 +493,7 @@ ev_annotation_set_modified (EvAnnotation *annot,
  */
 gboolean
 ev_annotation_set_modified_from_time (EvAnnotation *annot,
-				      GTime         utime)
+				      gint64        utime)
 {
 	gchar *modified;
 
@@ -565,8 +564,11 @@ ev_annotation_set_color (EvAnnotation   *annot,
     g_return_val_if_fail (EV_IS_ANNOTATION (annot), FALSE);
 
     ev_annotation_get_color (annot, &annot_color);
-    if (color == NULL || gdk_color_equal (color, &annot_color))
-        return FALSE;
+    if (color == NULL ||
+        ((color->red == annot_color.red) &&
+        (color->green == annot_color.green) &&
+        (color->blue == annot_color.blue)))
+            return FALSE;
 
     rgba.red = color->red / 65535.;
     rgba.green = color->green / 65535.;
