@@ -23,6 +23,7 @@
 #include <string.h>
 #include <math.h>
 
+#include <glib.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkx.h>
 
@@ -214,7 +215,7 @@ ev_document_misc_surface_from_pixbuf (GdkPixbuf *pixbuf)
 	gdk_cairo_set_source_pixbuf (cr, pixbuf, 0, 0);
 	cairo_paint (cr);
 	cairo_destroy (cr);
-	
+
 	return surface;
 }
 
@@ -249,7 +250,7 @@ ev_document_misc_surface_rotate_and_scale (cairo_surface_t *surface,
 
 	width = cairo_image_surface_get_width (surface);
 	height = cairo_image_surface_get_height (surface);
-	
+
 	if (dest_width == width &&
 	    dest_height == height &&
 	    dest_rotation == 0) {
@@ -280,14 +281,14 @@ ev_document_misc_surface_rotate_and_scale (cairo_surface_t *surface,
 			cairo_translate (cr, 0, 0);
 	}
 	cairo_rotate (cr, dest_rotation * G_PI / 180.0);
-	
+
 	if (dest_width != width || dest_height != height) {
 		cairo_pattern_set_filter (cairo_get_source (cr), CAIRO_FILTER_BILINEAR);
 		cairo_scale (cr,
 			     (gdouble)dest_width / width,
 			     (gdouble)dest_height / height);
 	}
-	
+
 	cairo_set_source_surface (cr, surface, 0, 0);
 	cairo_paint (cr);
 	cairo_destroy (cr);
@@ -339,41 +340,37 @@ ev_document_misc_invert_pixbuf (GdkPixbuf *pixbuf)
 }
 
 gdouble
-ev_document_misc_get_screen_dpi (GdkScreen *screen, GdkMonitor *monitor)
+ev_document_misc_get_monitor_dpi (GdkMonitor *monitor)
 {
+	GdkRectangle geometry;
+	int s;
 	gdouble dp, di;
 
+	gdk_monitor_get_geometry (monitor, &geometry);
+	s = gdk_monitor_get_scale_factor (monitor);
+
 	/*diagonal in pixels*/
-	dp = hypot (WidthOfScreen (gdk_x11_screen_get_xscreen (screen)), HeightOfScreen (gdk_x11_screen_get_xscreen (screen)));
+	dp = hypot (geometry.width * s, geometry.height * s);
 
 	/*diagonal in inches*/
 	di = hypot (gdk_monitor_get_width_mm(monitor), gdk_monitor_get_height_mm (monitor)) / 25.4;
-	di /= gdk_monitor_get_scale_factor (monitor);
 
 	return (dp / di);
 }
 
 /* Returns a locale specific date and time representation */
 gchar *
-ev_document_misc_format_date (GTime utime)
+ev_document_misc_format_date (gint64 utime)
 {
-	time_t time = (time_t) utime;
-	char s[256];
-	const char fmt_hack[] = "%c";
-	size_t len;
-#ifdef HAVE_LOCALTIME_R
-	struct tm t;
-	if (time == 0 || !localtime_r (&time, &t)) return NULL;
-	len = strftime (s, sizeof (s), fmt_hack, &t);
-#else
-	struct tm *t;
-	if (time == 0 || !(t = localtime (&time)) ) return NULL;
-	len = strftime (s, sizeof (s), fmt_hack, t);
-#endif
+	GDateTime *date_time;
+	gchar     *result = NULL;
 
-	if (len == 0 || s[0] == '\0') return NULL;
-
-	return g_locale_to_utf8 (s, -1, NULL, NULL, NULL);
+	date_time = g_date_time_new_from_unix_local (utime);
+	if (date_time != NULL) {
+		result = g_date_time_format (date_time, "%c");
+		g_date_time_unref (date_time);
+	}
+	return result;
 }
 
 void
