@@ -28,8 +28,6 @@
 #include "synctex_parser.h"
 #include "ev-file-helpers.h"
 
-#define EV_DOCUMENT_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), EV_TYPE_DOCUMENT, EvDocumentPrivate))
-
 typedef struct _EvPageSize
 {
 	gdouble width;
@@ -56,7 +54,7 @@ struct _EvDocumentPrivate
 	EvPageSize     *page_sizes;
 	EvDocumentInfo *info;
 
-	synctex_scanner_t synctex_scanner;
+	synctex_scanner_p synctex_scanner;
 };
 
 static gint            _ev_document_get_n_pages     (EvDocument *document);
@@ -72,7 +70,7 @@ static gboolean        _ev_document_support_synctex (EvDocument *document);
 static GMutex ev_doc_mutex;
 static GMutex ev_fc_mutex;
 
-G_DEFINE_ABSTRACT_TYPE (EvDocument, ev_document, G_TYPE_OBJECT)
+G_DEFINE_ABSTRACT_TYPE_WITH_PRIVATE (EvDocument, ev_document, G_TYPE_OBJECT)
 
 GQuark
 ev_document_error_quark (void)
@@ -138,7 +136,8 @@ ev_document_finalize (GObject *object)
 static void
 ev_document_init (EvDocument *document)
 {
-	document->priv = EV_DOCUMENT_GET_PRIVATE (document);
+	document->priv = ev_document_get_instance_private (document);
+	document->synctex_version = SYNCTEX_VERSION_STRING;
 
 	/* Assume all pages are the same size until proven otherwise */
 	document->priv->uniform = TRUE;
@@ -151,8 +150,6 @@ ev_document_class_init (EvDocumentClass *klass)
 {
 	GObjectClass *g_object_class = G_OBJECT_CLASS (klass);
 
-	g_type_class_add_private (g_object_class, sizeof (EvDocumentPrivate));
-
 	klass->get_page = ev_document_impl_get_page;
 	klass->get_info = ev_document_impl_get_info;
 	klass->get_backend_info = NULL;
@@ -203,7 +200,7 @@ ev_document_fc_mutex_trylock (void)
  * @error: a #GError location to store an error, or %NULL
  *
  * Loads @document from @uri.
- * 
+ *
  * On failure, %FALSE is returned and @error is filled in.
  * If the document is encrypted, EV_DEFINE_ERROR_ENCRYPTED is returned.
  * If the backend cannot load the specific document, EV_DOCUMENT_ERROR_INVALID
@@ -229,7 +226,7 @@ ev_document_load (EvDocument  *document,
 
 	if ( !g_strcmp0 (ev_file_get_mime_type(uri,TRUE,&err),"application/epub+zip") )
 		document->iswebdocument=TRUE ;
-		
+
 	retval = klass->load (document, uri, &err);
 	if (!retval) {
 		if (err) {
@@ -255,7 +252,7 @@ ev_document_load (EvDocument  *document,
 		priv->uri = g_strdup (uri);
 
 		priv->n_pages = _ev_document_get_n_pages (document);
-		
+
 		for (i = 0; i < priv->n_pages; i++) {
 
 			/*
@@ -263,13 +260,13 @@ ev_document_load (EvDocument  *document,
 			 * We are however geeneralising the scenario by considering epub as a type of web document.
 			 * FIXME: Labels, or bookmarks though, can be done.
 			 */
-			
+
 			EvPage     *page = ev_document_get_page (document, i);
 			gdouble     page_width = 0;
 			gdouble     page_height = 0;
 			EvPageSize *page_size;
 			gchar      *page_label;
-			
+
 			if ( document->iswebdocument == FALSE ) {
 				_ev_document_get_page_size (document, page, &page_width, &page_height);
 			}
@@ -278,7 +275,7 @@ ev_document_load (EvDocument  *document,
 				page_width = 800;
 				page_height= 600;
 			}
-			
+
 			if (i == 0) {
 				priv->uniform_width = page_width;
 				priv->uniform_height = page_height;
@@ -298,9 +295,9 @@ ev_document_load (EvDocument  *document,
 				    priv->uniform_height != page_height)) {
 				/* It's a different page size.  Backfill the array. */
 				int j;
-				
+
 				priv->page_sizes = g_new0 (EvPageSize, priv->n_pages);
-				
+
 				for (j = 0; j < i; j++) {
 					page_size = &(priv->page_sizes[j]);
 					page_size->width = priv->uniform_width;
@@ -361,7 +358,7 @@ ev_document_load (EvDocument  *document,
  * @error: a #GError location to store an error, or %NULL
  *
  * Saves @document to @uri.
- * 
+ *
  * Returns: %TRUE on success, or %FALSE on error with @error filled in
  */
 gboolean
@@ -421,7 +418,7 @@ ev_document_synctex_backward_search (EvDocument *document,
                                      gfloat      y)
 {
         EvSourceLink *result = NULL;
-        synctex_scanner_t scanner;
+        synctex_scanner_p scanner;
 
         g_return_val_if_fail (EV_IS_DOCUMENT (document), NULL);
 
@@ -430,10 +427,10 @@ ev_document_synctex_backward_search (EvDocument *document,
                 return NULL;
 
         if (synctex_edit_query (scanner, page_index + 1, x, y) > 0) {
-                synctex_node_t node;
+                synctex_node_p node;
 
                 /* We assume that a backward search returns either zero or one result_node */
-                node = synctex_next_result (scanner);
+                node = synctex_scanner_next_result (scanner);
                 if (node != NULL) {
                         const gchar *filename;
 
@@ -466,7 +463,7 @@ ev_document_synctex_forward_search (EvDocument   *document,
 				    EvSourceLink *link)
 {
         EvMapping        *result = NULL;
-        synctex_scanner_t scanner;
+        synctex_scanner_p scanner;
 
         g_return_val_if_fail (EV_IS_DOCUMENT (document), NULL);
 
@@ -474,11 +471,11 @@ ev_document_synctex_forward_search (EvDocument   *document,
         if (!scanner)
                 return NULL;
 
-        if (synctex_display_query (scanner, link->filename, link->line, link->col) > 0) {
-                synctex_node_t node;
+        if (synctex_display_query (scanner, link->filename, link->line, link->col, 0) > 0) {
+                synctex_node_p node;
                 gint           page;
 
-                if ((node = synctex_next_result (scanner))) {
+                if ((node = synctex_scanner_next_result (scanner))) {
                         result = g_new (EvMapping, 1);
 
                         page = synctex_node_page (node) - 1;
@@ -780,7 +777,7 @@ EvDocumentInfo *
 ev_document_info_copy (EvDocumentInfo *info)
 {
 	EvDocumentInfo *copy;
-	
+
 	g_return_val_if_fail (info != NULL, NULL);
 
 	copy = g_new0 (EvDocumentInfo, 1);
@@ -793,7 +790,7 @@ ev_document_info_copy (EvDocumentInfo *info)
 	copy->creator = g_strdup (info->creator);
 	copy->producer = g_strdup (info->producer);
 	copy->linearized = g_strdup (info->linearized);
-	
+
 	copy->creation_date = info->creation_date;
 	copy->modified_date = info->modified_date;
 	copy->layout = info->layout;
@@ -821,11 +818,7 @@ ev_document_info_free (EvDocumentInfo *info)
 	g_free (info->keywords);
 	g_free (info->creator);
 	g_free (info->producer);
-
-	if (info->linearized != 0 && info->linearized != 1)
-	{
-		g_free(info->linearized);
-	}
+	g_free (info->linearized);
 
 	g_free (info->security);
 	ev_document_license_free (info->license);
