@@ -22,13 +22,13 @@ typedef struct _CacheJobInfo
 	/* Device scale factor of target widget */
 	int device_scale;
 
-	/* Selection data. 
+	/* Selection data.
 	 * Selection_points are the coordinates encapsulated in selection.
 	 * target_points is the target selection size. */
 	EvRectangle      target_points;
 	EvSelectionStyle selection_style;
 	gboolean         points_set;
-	
+
 	cairo_surface_t *selection;
 	gdouble          selection_scale;
 	EvRectangle      selection_points;
@@ -81,8 +81,6 @@ enum
 
 static guint signals[N_SIGNALS] = {0, };
 
-static void          ev_pixbuf_cache_init       (EvPixbufCache      *pixbuf_cache);
-static void          ev_pixbuf_cache_class_init (EvPixbufCacheClass *pixbuf_cache);
 static void          ev_pixbuf_cache_finalize   (GObject            *object);
 static void          ev_pixbuf_cache_dispose    (GObject            *object);
 static void          job_finished_cb            (EvJob              *job,
@@ -234,7 +232,7 @@ ev_pixbuf_cache_new (GtkWidget       *view,
 	EvPixbufCache *pixbuf_cache;
 
 	pixbuf_cache = (EvPixbufCache *) g_object_new (EV_TYPE_PIXBUF_CACHE, NULL);
-	/* This is a backlink, so we don't ref this */ 
+	/* This is a backlink, so we don't ref this */
 	pixbuf_cache->view = view;
 	pixbuf_cache->model = g_object_ref (model);
 	pixbuf_cache->document = ev_document_model_get_document (model);
@@ -258,22 +256,14 @@ ev_pixbuf_cache_set_max_size (EvPixbufCache *pixbuf_cache,
 static int
 get_device_scale (EvPixbufCache *pixbuf_cache)
 {
-#ifdef HAVE_HIDPI_SUPPORT
 	return gtk_widget_get_scale_factor (pixbuf_cache->view);
-#else
-	return 1;
-#endif
 }
 
 static void
 set_device_scale_on_surface (cairo_surface_t *surface,
                              int              device_scale)
 {
-#ifdef HAVE_HIDPI_SUPPORT
 	cairo_surface_set_device_scale (surface, device_scale, device_scale);
-#else
-	g_return_if_fail (device_scale == 1);
-#endif
 }
 
 static void
@@ -692,7 +682,7 @@ add_job (EvPixbufCache  *pixbuf_cache,
 		GdkColor text, base;
 
 		get_selection_colors (EV_VIEW (pixbuf_cache->view), &text, &base);
-		ev_job_render_set_selection_info (EV_JOB_RENDER (job_info->job), 
+		ev_job_render_set_selection_info (EV_JOB_RENDER (job_info->job),
 						  &(job_info->target_points),
 						  job_info->selection_style,
 						  &text, &base);
@@ -1160,7 +1150,7 @@ static void
 update_job_selection (CacheJobInfo    *job_info,
 		      EvViewSelection *selection)
 {
-	job_info->points_set = TRUE;		
+	job_info->points_set = TRUE;
 	job_info->target_points = selection->rect;
 	job_info->selection_style = selection->style;
 }
@@ -1216,7 +1206,7 @@ ev_pixbuf_cache_set_selection_list (EvPixbufCache *pixbuf_cache,
 			if (((EvViewSelection *)list->data)->page == page) {
 				selection = list->data;
 				break;
-			} else if (((EvViewSelection *)list->data)->page > page) 
+			} else if (((EvViewSelection *)list->data)->page > page)
 				break;
 			list = list->next;
 		}
@@ -1235,7 +1225,7 @@ ev_pixbuf_cache_set_selection_list (EvPixbufCache *pixbuf_cache,
 			if (((EvViewSelection *)list->data)->page == page) {
 				selection = list->data;
 				break;
-			} else if (((EvViewSelection *)list->data)->page > page) 
+			} else if (((EvViewSelection *)list->data)->page > page)
 				break;
 			list = list->next;
 		}
@@ -1256,7 +1246,7 @@ ev_pixbuf_cache_set_selection_list (EvPixbufCache *pixbuf_cache,
 			if (((EvViewSelection *)list->data)->page == page) {
 				selection = list->data;
 				break;
-			} else if (((EvViewSelection *)list->data)->page > page) 
+			} else if (((EvViewSelection *)list->data)->page > page)
 				break;
 			list = list->next;
 		}
@@ -1301,7 +1291,7 @@ ev_pixbuf_cache_get_selection_list (EvPixbufCache *pixbuf_cache)
 				selection->covered_region = cairo_region_reference (pixbuf_cache->prev_job[i].selection_region);
 			retval = g_list_prepend (retval, selection);
 		}
-		
+
 		page ++;
 	}
 
@@ -1315,7 +1305,7 @@ ev_pixbuf_cache_get_selection_list (EvPixbufCache *pixbuf_cache)
 				selection->covered_region = cairo_region_reference (pixbuf_cache->job_list[i].selection_region);
 			retval = g_list_prepend (retval, selection);
 		}
-		
+
 		page ++;
 	}
 
@@ -1331,7 +1321,7 @@ ev_pixbuf_cache_get_selection_list (EvPixbufCache *pixbuf_cache)
 				selection->covered_region = cairo_region_reference (pixbuf_cache->next_job[i].selection_region);
 			retval = g_list_prepend (retval, selection);
 		}
-		
+
 		page ++;
 	}
 
