@@ -66,6 +66,7 @@ G_DEFINE_TYPE_EXTENDED (EvSidebarBookmarks,
                         ev_sidebar_bookmarks,
                         GTK_TYPE_BOX,
                         0,
+                        G_ADD_PRIVATE (EvSidebarBookmarks)
                         G_IMPLEMENT_INTERFACE (EV_TYPE_SIDEBAR_PAGE,
                                                ev_sidebar_bookmarks_page_iface_init))
 
@@ -418,9 +419,7 @@ ev_sidebar_bookmarks_init (EvSidebarBookmarks *sidebar_bookmarks)
         GtkCellRenderer           *renderer;
         GtkTreeSelection          *selection;
 
-        sidebar_bookmarks->priv = G_TYPE_INSTANCE_GET_PRIVATE (sidebar_bookmarks,
-                                                               EV_TYPE_SIDEBAR_BOOKMARKS,
-                                                               EvSidebarBookmarksPrivate);
+        sidebar_bookmarks->priv = ev_sidebar_bookmarks_get_instance_private (sidebar_bookmarks);
         priv = sidebar_bookmarks->priv;
 
         gtk_orientable_set_orientation (GTK_ORIENTABLE (sidebar_bookmarks), GTK_ORIENTATION_VERTICAL);
@@ -493,11 +492,13 @@ ev_sidebar_bookmarks_init (EvSidebarBookmarks *sidebar_bookmarks)
         gtk_widget_show (GTK_WIDGET (sidebar_bookmarks));
 
         /* Popup menu */
+        G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
         priv->action_group = gtk_action_group_new ("BookmarsPopupActions");
         gtk_action_group_set_translation_domain (priv->action_group, NULL);
         gtk_action_group_add_actions (priv->action_group, popup_entries,
                                       G_N_ELEMENTS (popup_entries),
                                       sidebar_bookmarks);
+        G_GNUC_END_IGNORE_DEPRECATIONS;
         priv->ui_manager = gtk_ui_manager_new ();
         gtk_ui_manager_insert_action_group (priv->ui_manager,
                                             priv->action_group, 0);
@@ -535,8 +536,6 @@ ev_sidebar_bookmarks_class_init (EvSidebarBookmarksClass *klass)
 
         widget_class->popup_menu = ev_sidebar_bookmarks_popup_menu;
 
-        g_type_class_add_private (g_object_class, sizeof (EvSidebarBookmarksPrivate));
-
         g_object_class_override_property (g_object_class, PROP_WIDGET, "main-widget");
 
         signals[ADD_BOOKMARK] =
